@@ -1,4 +1,5 @@
 from vcr.request import Request
+from . import compat
 try:
     import simplejson as json
 except ImportError:
@@ -11,22 +12,17 @@ def _json_default(obj):
     return obj
 
 
-def _fix_response_unicode(d):
-    d['body']['string'] = d['body']['string'].encode('utf-8')
-    return d
-
-
 def deserialize(cassette_string):
     data = json.loads(cassette_string)
     requests = [Request._from_dict(r['request']) for r in data]
-    responses = [_fix_response_unicode(r['response']) for r in data]
+    responses = [compat.convert_to_bytes(r['response']) for r in data]
     return requests, responses
 
 
 def serialize(cassette_dict):
     data = ([{
         'request': request._to_dict(),
-        'response': response,
+        'response': compat.convert_to_unicode(response),
     } for request, response in zip(
         cassette_dict['requests'],
         cassette_dict['responses']
